obelisk.types.TimestampPrecision
================================

.. currentmodule:: obelisk.types

.. autoclass:: TimestampPrecision
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TimestampPrecision.SECONDS
      ~TimestampPrecision.MILLISECONDS
      ~TimestampPrecision.MICROSECONDS
   
   